Crate links_notation

Crate links_notation 

Re-exports

pub use parser_config::ParserConfig;

Modules

comments
Comments, and the rule that decides where one starts.
format_config
parser
parser_config

Macros

lino
Procedural macro that provides compile-time validation of Links Notation syntax.

Structs

LiNoBuilder
Builder for creating LiNo links with arbitrary number of values.
SyntaxError
A syntax error, with the position in the document it was found at.

Enums

LiNo
ParseError
Error type for Lino parsing

Constants

VERSION
The version of this crate, taken from Cargo.toml at compile time.

Functions

format_links
Formats a collection of LiNo links as a multi-line string. Each link is formatted on a separate line.
format_links_with_config
Formats a collection of LiNo links as a multi-line string using FormatConfig. Supports all formatting options including consecutive link grouping.
parse_lino
Reads a document, with comments.
parse_lino_to_links
parse_lino_to_links_with_config
Reads a document into a collection of links the way config says to.
parse_lino_with_config
Reads a document the way config says to.

Type Aliases

LinkBuilderDeprecated
Type alias for backward compatibility (deprecated).