pub fn encode_document_with_limits(
document: &[LiNo<String>],
options: BinaryLinoOptions,
limits: &DecodeLimits,
) -> BinaryResult<LinksPacket>Expand description
Converts a native model into a packet using caller-selected work budgets.
pub fn encode_document_with_limits(
document: &[LiNo<String>],
options: BinaryLinoOptions,
limits: &DecodeLimits,
) -> BinaryResult<LinksPacket>Converts a native model into a packet using caller-selected work budgets.