pub fn address_tier(address: u64, external_references: bool) -> BinaryResult<u8>Expand description
The narrowest width able to hold the internal address address.
pub fn address_tier(address: u64, external_references: bool) -> BinaryResult<u8>The narrowest width able to hold the internal address address.