LiNo

Enum LiNo 

pub enum LiNo<T> {
    Link {
        id: Option<T>,
        values: Vec<Self>,
    },
    Ref(T),
}

Variants

Fields

id: Option<T>
values: Vec<Self>


Ref(T)

Implementations

Source

impl<T> LiNo<T>

pub fn is_ref(&self) -> bool

pub fn new(id: Option<T>, values: Vec<Self>) -> Self

Creates a new link with the given ID and values.

This method allows creating links with any number of values, providing an alternative to tuple conversion for cases where more than 12 values are needed.

Examples
use links_notation::LiNo;

// Create a link with many values
let values: Vec<LiNo<String>> = (1..=20)
    .map(|i| LiNo::Ref(format!("v{}", i)))
    .collect();
let link = LiNo::new(Some("id".to_string()), values);
pub fn anonymous(values: Vec<Self>) -> Self

Creates a new anonymous link (no ID) with the given values.

Examples
use links_notation::LiNo;

let values = vec![LiNo::Ref("a".to_string()), LiNo::Ref("b".to_string())];
let link = LiNo::anonymous(values);
assert_eq!(format!("{}", link), "(a b)");
pub fn reference(value: T) -> Self

Creates a new reference.

Examples
use links_notation::LiNo;

let r: LiNo<String> = LiNo::reference("hello".to_string());
assert_eq!(format!("{}", r), "hello");
Source

impl<T: ToString + Clone> LiNo<T>

pub fn format_with_config(&self, config: &FormatConfig) -> String

Format the link using FormatConfig configuration.

Arguments
  • config - The FormatConfig to use for formatting
Returns

Formatted string representation