pub struct StreamPosition {
pub line: usize,
pub column: usize,
pub offset: usize,
pub buffered: usize,
}Expand description
The point immediately after the last character written to a stream parser.
Fields
line: usizeOne-based line number.
column: usizeOne-based character column.
offset: usizeAbsolute byte offset from the start of the stream.
buffered: usizeBytes held for the one unresolved top-level record.