Module parser

Module parser 

Structs

Link
ParseFailure
Where the parser stopped, and what it could have accepted there.
ParserState
SavedContext
Indentation state of the context a parenthesized group was opened in.

Functions

parse_document
parse_document_with_diagnostics
Parses a document and, when it does not parse, says where it stopped.